%
% Harmonic method for physical properties - seismic velocities
%
% David Mainprice 7/03/2019
% 
%% clear all
%clear all
%close all
%**************************************************************************
% Define elastic constants
%**************************************************************************
% crystal symmetry - Orthorhombic mmm
% Olivine structure (4.7646 10.2296 5.9942 90.00 90.00 90.00)

cs_tensor = crystalSymmetry('mmm',[4.7646,10.2296,5.9942],...
  'x||a','z||c','mineral','Olivine');
% *Import 4th rank tensor as 6 by 6 matrix*
% Olivine elastic stiffness (Cij) tensor in GPa
% Abramson E.H., Brown J.M., Slutsky L.J., and Zaug J.(1997)
% The elastic constants of San Carlos olivine to 17 GPa.
% Journal of Geophysical Research 102: 12253-12263.
%
% Enter tensor as 6 by 6 matrix,M line by line.
M = [[320.5  68.15  71.6     0     0     0];...
    [ 68.15  196.5  76.8     0     0     0];...
    [  71.6   76.8 233.5     0     0     0];...
    [   0      0      0     64     0     0];...
    [   0      0      0      0    77     0];...
    [   0      0      0      0     0  78.7]];
% Define density (g/cm3)
rho=3.355;
% Define tensor object in MTEX
% Cij -> Cijkl - elastic stiffness tensor
C = stiffnessTensor(M,cs_tensor,'density',rho);
%**************************************************************************
%% 3d surface with radius vector with vp values
%**************************************************************************
[vp,vs1,vs2,pp,ps1,ps2] = C.velocity('harmonic');
% propagation vectors
prop = S2AxisFieldHarmonic.normal;
close all
figure
surf(vp)
hold on
% propogation vectors
plot(prop,'3D','color','k','LineWidth',3,'add2all')
hold on
% P-wave polarization vectors
plot(pp,'3D','color','m','LineWidth',5,'add2all')
hold off
% set colour map to seismic color map : red2blueColorMap
% Red = slow to Blue = fast in Seismology
colormap(red2blueColorMap)